@@ -24,9 +24,7 @@ class One_Class_SVM:
         :rtype: pd.dataframe
             class by o-svm
         """
-        return DataFrame(
-            df["tokens"][classifier.index[classifier.iloc[:, i] == 1].tolist()]
-        )
+        return df.iloc[classifier.index[classifier.iloc[:, i] == 1].tolist()]
 
     @staticmethod
     def classification(
@@ -35,41 +33,36 @@ class One_Class_SVM:
         nus,
         quality_train=0.85,
         min_pred=0.05,
-        max_pred=0.2
+        max_pred=0.2,
+        gamma="auto",
+        kernel="rbf",
     ):
+        """[summary]
+
+        Args:
+            training (DataFrame): training dataset of preprocessed documents
+            predicting (DataFrame): target dataset of preprccessed documents
+            nus (list of floats): hyperparameters over which are looped. For each nu the classifier is trained
+            quality_train (float, optional): percentage of training data that seems to
+                                    belong to target class. Default: 0.85. Defaults to 0.85.
+            min_pred (float, optional): percentage of target data that has to be at
+                               least classified as belonging to target class
+            for classifier to be considered. Default: 0.0. Defaults to 0.05.
+            max_pred (float, optional): percentage of target class that is maximally
+                               allowed to be classified as belonging to
+            target class for classifier to be considered.. Defaults to 0.2.
+            gamma (str, optional): Hyperparamter of O-SVM. Defaults to "auto".
+            kernel (str, optional): Kernel function used in O_SVM. Defaults to "rbf".
+
+        Returns:
+            pd.DataFrame: DataFrame with
+                          stored classifiers that fulfill conditions
         """
-        trains a one-class SVM on the out-of-domain training data
 
-
-        :param training: training dataset of preprocessed documents
-        :type training: pd.DataFrame
-        :param predicting: target dataset of preprccessed documents
-        :type predicting: pd.DataFrame
-        :param nus: hyperparameters over which are looped. For each nu
-            the classifiers is trained
-        :type nus: list of floats
-        :param quality_train: percentage of training data that seems to
-            belong to target class, defaults to 0.85
-        :type quality_train: float
-        :param min_pred: percentage of target data that has to be at
-            least classified as belonging to target class
-            for classifier to be considered ,defaults to 0.05
-        :type min_pred: float
-        :param max_pred: percentage of target class that is maximally
-            allowed to be classified as belonging to
-            target class for classifier to be considered, defaults to 0.2
-        :type max_pred: float
-
-
-
-        :return: DataFrame with stored classifiers that
-            fulfill conditions
-        :rtype: pd.DataFrame
-        """
         df = DataFrame()
         for i in nus:
 
-            svm = OneClassSVM(nu=i, gamma="auto", kernel="rbf")
+            svm = OneClassSVM(nu=i, gamma=gamma, kernel=kernel)
             # fit the model for each kernel
             clf = svm.fit(training)
 
